@@ -1,6 +1,6 @@
 //! # twilight-lavalink
 //!
-//! [![discord badge][]][discord link] [![github badge][]][github link] [![license badge][]][license link] ![rust badge]
+//! [![codecov badge][]][codecov link] [![discord badge][]][discord link] [![github badge][]][github link] [![license badge][]][license link] ![rust badge]
 //!
 //! `twilight-lavalink` is a client for [Lavalink] as part of the twilight
 //! ecosystem.
@@ -89,14 +89,20 @@
 //! }
 //! ```
 //!
+//! There is also an example of a basic bot located in the [root of the
+//! `twilight` repository][github examples link].
+//!
 //! [Lavalink]: https://github.com/freyacodes/Lavalink
 //! [`async-tungstenite`]: https://crates.io/crates/async-tungstenite
 //! [`http`]: https://crates.io/crates/http
 //! [`rustls`]: https://crates.io/crates/rustls
 //! [client]: Lavalink
+//! [codecov badge]: https://img.shields.io/codecov/c/gh/twilight-rs/twilight?logo=codecov&style=for-the-badge&token=E9ERLJL0L2
+//! [codecov link]: https://app.codecov.io/gh/twilight-rs/twilight/
 //! [discord badge]: https://img.shields.io/discord/745809834183753828?color=%237289DA&label=discord%20server&logo=discord&style=for-the-badge
 //! [discord link]: https://discord.gg/7jj8n7D
 //! [github badge]: https://img.shields.io/badge/github-twilight-6f42c1.svg?style=for-the-badge&logo=github
+//! [github examples link]: https://github.com/twilight-rs/twilight/tree/main/examples
 //! [github link]: https://github.com/twilight-rs/twilight
 //! [license badge]: https://img.shields.io/badge/license-ISC-blue.svg?style=for-the-badge&logo=pastebin
 //! [license link]: https://github.com/twilight-rs/twilight/blob/main/LICENSE.md
@@ -122,7 +128,7 @@ pub mod model;
 pub mod node;
 pub mod player;
 
-#[cfg(feature = "http")]
+#[cfg(feature = "http-support")]
 pub mod http;
 
 pub use self::{client::Lavalink, node::Node, player::PlayerManager};
